@@ -62,7 +62,9 @@ fn main() {
   let future = async move {
     let ast_parser = CapturingSourceParser::new();
     let graph = create_graph(
-      source_file.clone(),
+      vec![source_file.clone()],
+      false,
+      None,
       &mut loader,
       None,
       None,
